@@ -20,11 +20,17 @@ class Touchscreen(devices.InputDevice):
             logging.debug("Touch event registered - {}".format(touch_event))
             # Flatten list. This essentially throws out all touch events that happen at an epoch shorter than the FPS.
             touch_event = touch_event[0]
+            pos_x = touch_event.x * self.config.width
+            pos_y = touch_event.y * self.config.height
+            dist_x = touch_event.dx * self.config.width
+            dist_y = touch_event.dy * self.config.height
+            name = "left" if pos_x >= (self.config.width / 2) else "right"
             return models.Response(
                 timestamp=datetime.datetime.now().isoformat(),
-                pos_x=touch_event.x * self.config.width,
-                pos_y=touch_event.y * self.config.height,
-                dist_x=touch_event.dx * self.config.width,
-                dist_y=touch_event.dy * self.config.height,
+                name=name,
+                pos_x=pos_x,
+                pos_y=pos_y,
+                dist_x=dist_x,
+                dist_y=dist_y,
             )
         return None
