@@ -59,7 +59,7 @@ class Stimulus(pg.sprite.Sprite, mixins.BaseClassMixin, mixins.WebFormMixin):
         self.height = self.screen.get_height()
         self.width = self.screen.get_width()
 
-        self.hidden = False
+        self.hidden = True
 
     def show(self):
         self.hidden = False
@@ -87,7 +87,7 @@ class Stimulus(pg.sprite.Sprite, mixins.BaseClassMixin, mixins.WebFormMixin):
 
     def get_details(self):
         """Returns a dictionary of stimulus attributes."""
-        return dict()
+        return {"id": self.get_identifier(), "common_name": self.get_common_name()}
 
     def generate_new_trial(self):
         """Regenerate stimuli for a fresh trial"""
